@@ -406,10 +406,11 @@ impl Kubectl {
 
     // TODO: implement provider fetch out of cluster
     pub(crate) async fn get_cluster_provider(&self) -> anyhow::Result<v0::Provider> {
-        let nodes = self.all_nodes().await?;
-        if is_aks(nodes) {
+        let nodes = self.all_nodes().await?.into_iter().collect::<Vec<_>>();
+
+        if is_aks(&nodes) {
             Ok(v0::Provider::Aks)
-        } else if is_eks() {
+        } else if is_eks(&nodes) {
             Ok(v0::Provider::Eks)
         } else {
             Ok(v0::Provider::Generic)
