@@ -59,11 +59,13 @@ impl Kubectl {
 
     pub(super) async fn check_statehub_cluster_crd(&self) -> anyhow::Result<String> {
         let name = StatehubCluster::crd().name();
-        let crds = self.api::<CustomResourceDefinition>().await?;
-        crds.get(&name)
+        let version = StatehubCluster::api_resource().version;
+        self.api::<CustomResourceDefinition>()
+            .await?
+            .get(&name)
             .await
-            .map(|crd| crd.name())
             .context("StatehubCluster CRD is not installed")
+            .map(|crd| format!("{}/{}", crd.name(), version))
     }
 
     pub(super) async fn check_statehub_cluster_object(&self) -> anyhow::Result<StatehubCluster> {
