@@ -106,3 +106,12 @@ where
         self.0.into_iter()
     }
 }
+
+impl<T> Default for Output<T>
+where
+    T: Default,
+{
+    fn default() -> Self {
+        Self(T::default())
+    }
+}
