@@ -1084,13 +1084,11 @@ impl StateHub {
 
         for kubectl in kubectls {
             self.inform(format_args!(
-                "Updating cluster with K8s context {} with {:?}",
+                "Updating cluster {} (kubeconfig context {})",
                 kubectl.cluster_name(),
-                azure
+                kubectl.context()
             ));
-            let azure = Some(&azure);
-            let aws = Some(&aws);
-            self.setup_credentials_helper(&kubectl, &namespace, aws, azure)
+            self.setup_credentials_helper(&kubectl, &namespace, &aws, &azure)
                 .await?;
         }
         Ok(())
