@@ -92,6 +92,10 @@ impl Config {
         let profile = profile.unwrap_or(&self.profile).to_string();
         self.profiles.entry(profile).or_default().token = Some(token.to_string());
     }
+
+    pub(crate) fn set_profile(&mut self, profile: impl ToString) {
+        self.profile = profile.to_string();
+    }
 }
 
 impl Default for Config {
