@@ -287,8 +287,8 @@ impl StateHub {
         self.setup_credentials_helper(
             &kubectl,
             &register_cluster.namespace,
-            Some(&register_cluster.aws),
-            Some(&register_cluster.azure),
+            &register_cluster.aws,
+            &register_cluster.azure,
         )
         .await?;
         self.setup_configmap_helper(&kubectl, &cluster, register_cluster)
@@ -609,23 +609,15 @@ or run following commands before running 'statehub register-cluster`
         &self,
         kubectl: &k8s::Kubectl,
         namespace: &str,
-        aws: Option<&AwsCredentials>,
-        azure: Option<&AzureCredentials>,
+        aws: &AwsCredentials,
+        azure: &AzureCredentials,
     ) -> anyhow::Result<()> {
-        let azure = if let Some(azure) = azure {
-            json::to_value(azure)?
-        } else {
-            json::json!({})
-        };
-        let _secret = kubectl.store_azure_credentials(namespace, azure).await?;
-
-        let aws = if let Some(aws) = aws {
-            json::to_value(aws)?
-        } else {
-            json::json!({})
-        };
+        let aws = json::to_value(aws)?;
         let _secret = kubectl.store_aws_credentials(namespace, aws).await?;
 
+        let azure = json::to_value(azure)?;
+        let _secret = kubectl.store_azure_credentials(namespace, azure).await?;
+
         Ok(())
     }
 
