@@ -3,18 +3,19 @@
 // Use is subject to license terms.
 //
 
-// use anyhow::Context;
-
 use crate::api::GitlabGenericPackage;
 
 use super::*;
 
 impl StateHub {
     pub(super) async fn latest_version(&self) -> anyhow::Result<semver::Version> {
-        api::Api::gitlab()
+        let bytes = api::Api::gitlab()
             .get_file(Self::PLATFORM, "latest", "version")
-            .await
-        //.context("Fetching latest version number from repository")
+            .await?;
+        String::from_utf8_lossy(&bytes)
+            .trim()
+            .parse()
+            .context("Reading latest/version")
     }
 
     pub(super) async fn get_package(
